#
# spec file for package nvidia-modprobe
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nvidia-modprobe
Version:        565.77
Release:        2.1
Summary:        NVIDIA kernel module loader
License:        GPL-2.0-or-later
URL:            http://www.nvidia.com/object/unix.html
ExclusiveArch:  x86_64 aarch64

Source0:        https://download.nvidia.com/XFree86/%{name}/%{name}-%{version}.tar.bz2
Patch0:         %{name}-man-page-permissions.patch
Patch1:         nvidia-modprobe-restrict-capability-file-path.patch
Patch2:         https://github.com/NVIDIA/nvidia-modprobe/pull/3.patch#/reproducible.patch

BuildRequires:  gcc
BuildRequires:  m4

PreReq:         permissions

%description
This utility is used by user-space NVIDIA driver components to make sure the
NVIDIA kernel modules are loaded and that the NVIDIA character device files are
present.

%prep
%autosetup -p1
# Remove additional CFLAGS added when enabling DEBUG
sed -i '/+= -O0 -g/d' utils.mk

%build
export CFLAGS="%{optflags}"
export LDFLAGS="%{?__global_ldflags}"
%make_build \
    DEBUG=1 \
    NV_VERBOSE=1 \
    PREFIX=%{_prefix} \
    STRIP_CMD=true

%install
%make_install \
    NV_VERBOSE=1 \
    PREFIX=%{_prefix} \
    STRIP_CMD=true

%verifyscript
%verify_permissions -e /usr/bin/nvidia-modprobe

%post
%set_permissions /usr/bin/nvidia-modprobe

%files
%license COPYING
%attr(4755, root, root) %{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.*

%changelog
* Thu Jan 23 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Fri Jan 17 2025 Stefan Dirsch <sndirsch@suse.com>
- nvidia-modprobe-restrict-capability-file-path.patch
  * fixes security issue (bsc#1230950, boo#1231257); patch is new
    in nvidia-modprobe 550.144.03 release for driver security
    release 550.144.03 (bsc#1235461, boo#1235871, CVE-2024-0131,
    CVE-2024-0147, CVE-2024-0149, CVE-2024-0150, CVE-2024-53869)
* Fri Dec  6 2024 Stefan Dirsch <sndirsch@suse.com>
- update to version 565.77
* Wed Nov  6 2024 Stefan Dirsch <sndirsch@suse.com>
- update to version 565.57.01
  - -> https://github.com/NVIDIA/nvidia-modprobe/commit/d58cdacf01207eb115728eeae59bb7eb0bff690b
* Tue Sep 24 2024 Stefan Dirsch <sndirsch@suse.com>
- created package
  - -> https://github.com/openSUSE/nvidia-driver-G06/issues/16
